#include <windows.h> 
#include <windowsx.h> 
#include "tapiCall.h" 
#include "tapi.h"

#define BUFSIZE 256

#if defined (WIN32)
	#define IS_WIN32 TRUE
#else
	#define IS_WIN32 FALSE
#endif

#define IS_NT      IS_WIN32 && (BOOL)(GetVersion() < 0x80000000)
#define IS_WIN32S  IS_WIN32 && (BOOL)(!(IS_NT) && (LOBYTE(LOWORD(GetVersion()))<4))
#define IS_WIN95   (BOOL)(!(IS_NT) && !(IS_WIN32S)) && IS_WIN32

HINSTANCE hInst;   // current instance
HWND hWnd;         // parent window handle
HWND hListWnd;     // listbox
HDC  hdc;
TEXTMETRIC  tm ;


LPCTSTR lpszAppName = "tapiRequestMakeCall";
LPCTSTR lpszTitle   = "Assisted Telephony Application"; 

BOOL RegisterWin95( CONST WNDCLASS* lpwc );


int APIENTRY WinMain( HINSTANCE hInstance, HINSTANCE hPrevInstance,
                      LPTSTR lpCmdLine, int nCmdShow)
{
   MSG      msg;
   WNDCLASS wc;

   wc.style         = CS_HREDRAW | CS_VREDRAW;
   wc.lpfnWndProc   = (WNDPROC)WndProc;       
   wc.cbClsExtra    = 0;                      
   wc.cbWndExtra    = 0;                      
   wc.hInstance     = hInstance;              
   wc.hIcon         = LoadIcon (hInstance, lpszAppName); 
   wc.hCursor       = LoadCursor(NULL, IDC_ARROW);
   wc.hbrBackground = (HBRUSH)(COLOR_WINDOW+1);
   wc.lpszMenuName  = lpszAppName;              
   wc.lpszClassName = lpszAppName;              

   if ( IS_WIN95 )
   {
      if ( !RegisterWin95( &wc ) )
         return( FALSE );
   }
   else if ( !RegisterClass( &wc ) )
      return( FALSE );

   hInst = hInstance; 

   hWnd = CreateWindow( lpszAppName, 
                        lpszTitle,    
                        WS_OVERLAPPEDWINDOW, 
                        CW_USEDEFAULT, 0, 
                        CW_USEDEFAULT, 0,  
                        NULL,              
                        NULL,              
                        hInstance,         
                        NULL               
                      );

   if ( !hWnd ) 
      return( FALSE );

   ShowWindow( hWnd, nCmdShow ); 
   UpdateWindow( hWnd );         

   while( GetMessage( &msg, NULL, 0, 0) )   
   {
      TranslateMessage( &msg ); 
      DispatchMessage( &msg );  
   }

   return( msg.wParam ); 
}


BOOL RegisterWin95( CONST WNDCLASS* lpwc )
{
	WNDCLASSEX wcex;

   wcex.style         = lpwc->style;
   wcex.lpfnWndProc   = lpwc->lpfnWndProc;
   wcex.cbClsExtra    = lpwc->cbClsExtra;
   wcex.cbWndExtra    = lpwc->cbWndExtra;
   wcex.hInstance     = lpwc->hInstance;
   wcex.hIcon         = lpwc->hIcon;
   wcex.hCursor       = lpwc->hCursor;
   wcex.hbrBackground = lpwc->hbrBackground;
   wcex.lpszMenuName  = lpwc->lpszMenuName;
   wcex.lpszClassName = lpwc->lpszClassName;

   // Added elements for Windows 95.
   //...............................
   wcex.cbSize = sizeof(WNDCLASSEX);
   wcex.hIconSm = LoadImage(wcex.hInstance, lpwc->lpszClassName, 
                            IMAGE_ICON, 16, 16,
                            LR_DEFAULTCOLOR );
			
   return RegisterClassEx( &wcex );
}


LONG lRet;
char buf[BUFSIZE];
char szName[BUFSIZE];
char szNumber[BUFSIZE];
char szCountry[8];
char szAreaCd[8];
char szCanonical[15];
char szComment[BUFSIZE]; 


LRESULT CALLBACK WndProc( HWND hWnd, UINT uMsg, WPARAM wParam, LPARAM lParam )
{
   switch( uMsg )
   {
      case WM_COMMAND :
         switch( LOWORD( wParam ) )
         {
          	case IDM_DIAL  :
			    DialogBox( hInst, "IDD_DIALNUM", hWnd, (DLGPROC)Dial );
           		return( DefWindowProc( hWnd, uMsg, wParam, lParam ) );	  
            
		           
            case IDM_ABOUT :
            	DialogBox( hInst, "AboutBox", hWnd, (DLGPROC)About );
                break;

            case IDM_EXIT :
              	DestroyWindow( hWnd );
               	break;
	     }
      
       case WM_CREATE :

          hdc = GetDC (hWnd) ;
          GetTextMetrics (hdc, &tm) ;
          ReleaseDC (hWnd, hdc) ;
 
          hListWnd = CreateWindow ("listbox", NULL,
                              WS_CHILD | WS_VISIBLE, 
                              tm.tmAveCharWidth, tm.tmHeight * 3,
                              tm.tmAveCharWidth * 16 +
                                   GetSystemMetrics (SM_CXVSCROLL),
                              tm.tmHeight * 5,
                              hWnd, (HMENU)1,
                              (HINSTANCE) hInst, NULL) ;

          break;
      
      	case WM_SIZE:
        	MoveWindow(hListWnd, 0, 0, LOWORD(lParam), HIWORD(lParam), TRUE);
         	break;
  

      case WM_DESTROY :
              PostQuitMessage(0);
              break;
            
      default :
            return( DefWindowProc( hWnd, uMsg, wParam, lParam ) );
   }

   return( 0L );
}




/****************************************************************************
    FUNCTION: tapiError
    PURPOSE:  Assisted Telphony error messages
****************************************************************************/
void tapiError (LONG lrc)
{
 switch (lrc) {
    case TAPIERR_NOREQUESTRECIPIENT:
       MessageBox (hWnd, "No request recipient.", "", MB_OK);
       break;
    case TAPIERR_REQUESTQUEUEFULL:
       MessageBox (hWnd,"The request queue is full, try again later.", "", 
                   MB_OK);
       break;
    case TAPIERR_INVALDESTADDRESS:
       MessageBox (hWnd, "Invalid destination address.", "", MB_OK);
       break;
	
	case TAPIERR_REQUESTFAILED:
       MessageBox (hWnd, "The request failed for an unknown reason.", "", MB_OK);
       break;

	case TAPIERR_INVALPOINTER:
       MessageBox (hWnd, "An invalid pointer was passed in as a paramater.", "", MB_OK);
       break;
	
	default:
	   MessageBox (hWnd, "Unknown Error.", "", MB_OK);
       break;
		
    }
	
       	  
}

LRESULT CALLBACK About( HWND hDlg,           
                        UINT message,        
                        WPARAM wParam,       
                        LPARAM lParam)
{
   switch (message) 
   {
       case WM_INITDIALOG: 
               return (TRUE);

       case WM_COMMAND:                              
               if (   LOWORD(wParam) == IDOK         
                   || LOWORD(wParam) == IDCANCEL)    
               {
                       EndDialog(hDlg, TRUE);        
                       return (TRUE);
               }
               break;
   }

   return (FALSE); 
}


LRESULT CALLBACK Dial ( HWND hDlg,           // window handle of the dialog box
                        UINT message,        // type of message
                        WPARAM wParam,       // message-specific information
                        LPARAM lParam)
{
   switch (message) 
   {
       case WM_INITDIALOG:  // message: initialize dialog box
               {
                  lRet = tapiGetLocationInfo(szCountry, szAreaCd);
				      if (lRet > 0)
				   	    tapiError(lRet);
                  else
                  {
                     SetDlgItemText(hDlg, IDC_COUNTRYCODE, szCountry);
				         SetDlgItemText(hDlg, IDC_AREACODE, szAreaCd);
                  }
               }
               return (TRUE);

       case WM_COMMAND:                              // message: received a command
               if (   LOWORD(wParam) == IDOK )        // "OK" box selected?
               {
                  GetDlgItemText(hDlg, IDC_NAME, szName, 128);
				      GetDlgItemText(hDlg, IDC_NUMBER, szNumber, 128);
                  GetDlgItemText(hDlg, IDC_COUNTRYCODE, szCountry, 128);
                  GetDlgItemText(hDlg, IDC_AREACODE, szAreaCd, 128);
                  GetDlgItemText(hDlg, IDC_COMMENT, szComment, 128);
				      
				      strcat(szCanonical, szCountry);
                  strcat(szCanonical, "-");
                  strcat(szCanonical, szAreaCd);
                  strcat(szCanonical, "-");
                  strcat(szCanonical, szNumber);

				      lRet = tapiRequestMakeCall(szCanonical, lpszAppName, szName, szComment);
				      if (lRet > 0)
				   	    tapiError(lRet);

			   }			   
			 		
			   if (   LOWORD(wParam) == IDCANCEL)         // "OK" box selected?
               {
                       EndDialog(hDlg, TRUE);        // Exit the dialog
                       return (TRUE);
               }
               break;
   }

   return (FALSE); 
}




